# 📦 YPackage

Kişisel python modüllerim

- 📦 [PYPI](https://pypi.org/project/ypackage/)
- 🐙 [Github](https://github.com/yedhrab/YPackage)

> ✨ Yenilikler için [CHANAGELOG](https://github.com/yedhrab/YPackage/blob/master/docs/CHANGELOG.md) alanına bakın.

## 👨‍💼 CLI Uygulamaları

| ⭐ Uygulama | 👨‍💻 Komut | 📝 Açıklama | 
| -  |  - | - |
| [👨‍🎨 Tema Oluşturucu](https://github.com/yedhrab/YPackage/blob/master/docs/ythemecreator.md) | `ythemecreator` | 🎨 VS Code temalarının renk değerlerini değiştirerek yeni temalar üretir |
| 👨‍💼[ Dosya veya Dizin Adlandırıcı](https://github.com/yedhrab/YPackage/blob/master/docs/yfilerenamer.md) | `yfilerenamer` | 🗃️ Editörlerdeki yeniden adlandırma işlemleri gibi, dosya sistemindeki dosya veya dizinleri topluca yeniden adlandırmayı sağlar |
| [🔗 Google Drive Link Dönüştürücü](https://github.com/yedhrab/YPackage/blob/master/docs/ygoogledrive.md) | `ygoogledrive` | 💱 Google Drive'ın verdiği ön izleme bağlantılarını indilirebilir bağlantıya dönüştürür |
| [🔍 Google Arama Motoru](https://github.com/yedhrab/YPackage/blob/master/docs/ygooglesearch.md) | `ygooglesearch` | 📋 Google arama motoru üzerinde, verilen sorgunun sonuçlarını dosyaya raporlar |
|[💫 GitBook Entegrasyonu](https://github.com/yedhrab/YPackage/blob/master/docs/ygitbookintegration.md) | `ygitbookintegration` | 🤝 GitHub projerini GitBook üzerinden sunmak için gerekli dönüşümleri yapar |

## 👨‍💻 Geliştirici Notları

- 🧱 Temel kullanım `import ypackage` şeklindedir
- 🖤 CLI işlemlerine `ypackage.cli` içerisinde bulunur
- 💎 Çekirdek modüllere `ypackage.<modül>` şeklinde erişilir

| 🍱 Modül		| 📝 Açıklama								 |
| ------------ | ---------------------------------------- |
| `common`	 | 🌟 Sık kullandığum metotlar			  |
| `filesystem` | 📂 Dosya işlemleri					   |
| `gdrive`	 | 🔗 Google drive link dönüştürücü		 |
| `gitbook`	| 📖 GitBook için scriptlerim			  |
| `github`	 | 🐙 GitHub işlemleri					  |
| `markdown`   | 📑 Markdown scriptlerim				  |
| `regex`	  | 💎 Regex scriptlerim (yapılm aşamasında) |


## 💖 Destek ve İletişim

​[​![Github](https://raw.githubusercontent.com/yedhrab/YPackage/master/.github/assets/github_32px.png)​](https://github.com/yedhrab) [​![LinkedIn](https://raw.githubusercontent.com/yedhrab/YPackage/master/.github/assets/linkedin_32px.png)​](https://www.linkedin.com/in/yemreak/) [​![Website](https://raw.githubusercontent.com/yedhrab/YPackage/master/.github/assets/geography_32px.png)​](https://yemreak.com/) [​![Mail](https://raw.githubusercontent.com/yedhrab/YPackage/master/.github/assets/gmail_32px.png)​](mailto:yemreak.com@gmail.com?subject=YPackage%20%7C%20GitHub)​

​[​![Patreon](https://raw.githubusercontent.com/yedhrab/YPackage/master/.github/assets/become_a_patron_32px.png)](https://www.patreon.com/yemreak/)

## 🔏 Lisans

**The** [**Apache 2.0 License**](https://choosealicense.com/licenses/apache-2.0/) **©️ Yunus Emre Ak**

![YEmreAk](https://raw.githubusercontent.com/yedhrab/YPackage/master/.github/assets/ysigniture-trans.png)
